@@ -56,9 +56,9 @@ def convolve(array, kernel, boundary='fill', fill_value=0.,
         A flag indicating how to handle boundaries:
             * `None`
                 Set the ``result`` values to zero where the kernel
-                extends beyond the edge of the array (default).
+                extends beyond the edge of the array.
             * 'fill'
-                Set values outside the array boundary to ``fill_value``.
+                Set values outside the array boundary to ``fill_value`` (default).
             * 'wrap'
                 Periodic boundary that wrap to the other side of ``array``.
             * 'extend'
@@ -200,7 +200,7 @@ def convolve(array, kernel, boundary='fill', fill_value=0.,
         array_internal[mask != 0] = np.nan
     if np.ma.is_masked(kernel):
         # *kernel* doesn't support NaN interpolation, so instead we just fill it
-        kernel_internal = kernel.filled(fill_value)
+        kernel_internal = kernel_internal.filled(fill_value)
 
     # Mark the NaN values so we can replace them later if interpolate_nan is
     # not set
@@ -224,8 +224,6 @@ def convolve(array, kernel, boundary='fill', fill_value=0.,
 
     if not kernel_sums_to_zero:
         kernel_internal /= kernel_sum
-    else:
-        kernel_internal = kernel
 
     renormalize_by_kernel = not kernel_sums_to_zero
 
@@ -703,9 +701,6 @@ def convolve_fft(array, kernel, boundary='fill', fill_value=0.,
         # need to re-zero weights outside of the image (if it is padded, we
         # still don't weight those regions)
         bigimwt[arrayslices] = wtsm.real[arrayslices]
-        # curiously, at the floating-point limit, can get slightly negative numbers
-        # they break the min_wt=0 "flag" and must therefore be removed
-        bigimwt[bigimwt < 0] = 0
     else:
         bigimwt = 1
 
@@ -727,11 +722,14 @@ def convolve_fft(array, kernel, boundary='fill', fill_value=0.,
     if interpolate_nan:
         rifft = (ifftn(fftmult)) / bigimwt
         if not np.isscalar(bigimwt):
-            rifft[bigimwt < min_wt] = np.nan
-            if min_wt == 0.0:
-                rifft[bigimwt == 0.0] = 0.0
+            if min_wt > 0.:
+                rifft[bigimwt < min_wt] = np.nan
+            else:
+                # Set anything with no weight to zero (taking into account
+                # slight offsets due to floating-point errors).
+                rifft[bigimwt < 10 * np.finfo(bigimwt.dtype).eps] = 0.0
     else:
-        rifft = (ifftn(fftmult))
+        rifft = ifftn(fftmult)
 
     if preserve_nan:
         rifft[arrayslices][nanmaskarray] = np.nan
