@@ -17,6 +17,7 @@ from ..extern import six
 from . import angle_utilities as util
 from .. import units as u
 from ..utils import isiterable
+from ..utils.compat import NUMPY_LT_1_14_1
 
 __all__ = ['Angle', 'Latitude', 'Longitude']
 
@@ -430,25 +431,32 @@ class Angle(u.SpecificTypeQuantity):
             ok &= np.all(self < Angle(upper))
         return bool(ok)
 
-    def __str__(self):
+    def _str_helper(self, format=None):
         if self.isscalar:
-            return str(self.to_string())
+            return self.to_string(format=format)
+
+        if NUMPY_LT_1_14_1:
+            def formatter(x):
+                return x.to_string(format=format)
         else:
-            return np.array2string(self, formatter={'all': lambda x: x.to_string()})
+            # In numpy 1.14.1, array2print formatters get passed plain numpy scalars instead
+            # of subclass array scalars, so we need to recreate an array scalar.
+            def formatter(x):
+                return self._new_view(x).to_string(format=format)
+
+        return np.array2string(self, formatter={'all': formatter})
+
+    def __str__(self):
+        return self._str_helper()
 
     def _repr_latex_(self):
-        if self.isscalar:
-            return self.to_string(format='latex')
-        else:
-            # Need to do a magic incantation to convert to str.  Regular str
-            # or array2string causes all backslashes to get doubled.
-            return np.array2string(self, formatter={'all': lambda x: x.to_string(format='latex')})
+        return self._str_helper(format='latex')
 
 
 def _no_angle_subclass(obj):
     """Return any Angle subclass objects as an Angle objects.
 
-    This is used to ensure that Latitute and Longitude change to Angle
+    This is used to ensure that Latitude and Longitude change to Angle
     objects when they are used in calculations (such as lon/2.)
     """
     if isinstance(obj, tuple):
