@@ -62,7 +62,7 @@ def cirs_to_altaz(cirs_coo, altaz_frame):
                          # all below are already in correct units because they are QuantityFrameAttribues
                          altaz_frame.pressure.value,
                          altaz_frame.temperature.value,
-                         altaz_frame.relative_humidity,
+                         altaz_frame.relative_humidity.value,
                          altaz_frame.obswl.value)
 
     az, zen, _, _, _ = erfa.atioq(cirs_ra, cirs_dec, astrom)
@@ -102,7 +102,7 @@ def altaz_to_cirs(altaz_coo, cirs_frame):
                          # all below are already in correct units because they are QuantityFrameAttribues
                          altaz_coo.pressure.value,
                          altaz_coo.temperature.value,
-                         altaz_coo.relative_humidity,
+                         altaz_coo.relative_humidity.value,
                          altaz_coo.obswl.value)
 
     # the 'A' indicates zen/az inputs
