@@ -222,37 +222,51 @@ def setup_logging(outfile=None):
 
 
 def match_files(paths):
-    filelists = []
+    if os.path.isfile(paths[0]) and os.path.isfile(paths[1]):
+        # shortcut if both paths are files
+        return [paths]
 
-    for path in paths:
+    dirnames = [None, None]
+    filelists = [None, None]
+
+    for i, path in enumerate(paths):
         if glob.has_magic(path):
-            files = [os.path.abspath(f) for f in glob.glob(path)]
+            files = [os.path.split(f) for f in glob.glob(path)]
             if not files:
-                log.error('Wildcard pattern {!r} did not match '
-                          'any files.'.format(path))
+                log.error('Wildcard pattern %r did not match any files.', path)
                 sys.exit(2)
-            filelists.append(files)
+
+            dirs, files = list(zip(*files))
+            if len(set(dirs)) > 1:
+                log.error('Wildcard pattern %r should match only one '
+                          'directory.', path)
+                sys.exit(2)
+
+            dirnames[i] = set(dirs).pop()
+            filelists[i] = sorted(files)
         elif os.path.isdir(path):
-            filelists.append([os.path.abspath(f) for f in os.listdir(path)])
+            dirnames[i] = path
+            filelists[i] = sorted(os.listdir(path))
         elif os.path.isfile(path):
-            filelists.append([path])
+            dirnames[i] = os.path.dirname(path)
+            filelists[i] = [os.path.basename(path)]
         else:
             log.error(
-                '{!r} is not an existing file, directory, or wildcard pattern; '
-                'see `fitsdiff --help` for more usage help.'.format(path))
+                '%r is not an existing file, directory, or wildcard '
+                'pattern; see `fitsdiff --help` for more usage help.', path)
             sys.exit(2)
 
-    filelists[0].sort()
-    filelists[1].sort()
+        dirnames[i] = os.path.abspath(dirnames[i])
+
+    filematch = set(filelists[0]) & set(filelists[1])
 
     for a, b in [(0, 1), (1, 0)]:
-        if len(filelists[a]) > len(filelists[b]):
-            for extra in filelists[a][len(filelists[b]):]:
-                log.warning('{!r} has no match in {!r}'.format(extra, paths[b]))
-            filelists[a] = filelists[a][:len(filelists[b])]
-            break
+        if len(filelists[a]) > len(filematch) and not os.path.isdir(paths[a]):
+            for extra in sorted(set(filelists[a]) - filematch):
+                log.warning('%r has no match in %r', extra, dirnames[b])
 
-    return zip(*filelists)
+    return [(os.path.join(dirnames[0], f),
+             os.path.join(dirnames[1], f)) for f in filematch]
 
 
 def main(args=None):
