@@ -7,13 +7,14 @@ from math import cos, sin
 
 import pytest
 import numpy as np
-from numpy.testing import utils
+from numpy.testing import assert_allclose
 
 from .. import models
 from ...wcs import wcs
 
 
-@pytest.mark.parametrize(('inp'), [(0, 0), (4000, -20.56), (-2001.5, 45.9), (0, 90), (0, -90), (np.mgrid[:4, :6])])
+@pytest.mark.parametrize(('inp'), [(0, 0), (4000, -20.56), (-2001.5, 45.9),
+                                   (0, 90), (0, -90), (np.mgrid[:4, :6])])
 def test_against_wcslib(inp):
     w = wcs.WCS()
     crval = [202.4823228, 47.17511893]
@@ -30,8 +31,8 @@ def test_against_wcslib(inp):
     radec = w.wcs_pix2world(inp[0], inp[1], 1)
     xy = w.wcs_world2pix(radec[0], radec[1], 1)
 
-    utils.assert_allclose(m(*inp), radec, atol=1e-12)
-    utils.assert_allclose(minv(*radec), xy, atol=1e-12)
+    assert_allclose(m(*inp), radec, atol=1e-12)
+    assert_allclose(minv(*radec), xy, atol=1e-12)
 
 
 @pytest.mark.parametrize(('inp'), [(0, 0), (40, -20.56), (21.5, 45.9)])
@@ -39,27 +40,27 @@ def test_roundtrip_sky_rotaion(inp):
     lon, lat, lon_pole = 42, 43, 44
     n2c = models.RotateNative2Celestial(lon, lat, lon_pole)
     c2n = models.RotateCelestial2Native(lon, lat, lon_pole)
-    utils.assert_allclose(n2c.inverse(*n2c(*inp)), inp, atol=1e-13)
-    utils.assert_allclose(c2n.inverse(*c2n(*inp)), inp, atol=1e-13)
+    assert_allclose(n2c.inverse(*n2c(*inp)), inp, atol=1e-13)
+    assert_allclose(c2n.inverse(*c2n(*inp)), inp, atol=1e-13)
 
 
 def test_native_celestial_lat90():
     n2c = models.RotateNative2Celestial(1, 90, 0)
     alpha, delta = n2c(1, 1)
-    utils.assert_allclose(delta, 1)
-    utils.assert_allclose(alpha, 182)
+    assert_allclose(delta, 1)
+    assert_allclose(alpha, 182)
 
 
 def test_Rotation2D():
     model = models.Rotation2D(angle=90)
     x, y = model(1, 0)
-    utils.assert_allclose([x, y], [0, 1], atol=1e-10)
+    assert_allclose([x, y], [0, 1], atol=1e-10)
 
 
 def test_Rotation2D_inverse():
     model = models.Rotation2D(angle=234.23494)
     x, y = model.inverse(*model(1, 0))
-    utils.assert_allclose([x, y], [1, 0], atol=1e-10)
+    assert_allclose([x, y], [1, 0], atol=1e-10)
 
 
 def test_euler_angle_rotations():
@@ -71,13 +72,13 @@ def test_euler_angle_rotations():
 
     # rotate y into minus z
     model = models.EulerAngleRotation(0, 90, 0, 'zxz')
-    utils.assert_allclose(model(*z), y, atol=10**-12)
+    assert_allclose(model(*z), y, atol=10**-12)
     # rotate z into minus x
     model = models.EulerAngleRotation(0, 90, 0, 'zyz')
-    utils.assert_allclose(model(*z), negx, atol=10**-12)
+    assert_allclose(model(*z), negx, atol=10**-12)
     # rotate x into minus y
     model = models.EulerAngleRotation(0, 90, 0, 'yzy')
-    utils.assert_allclose(model(*x), negy, atol=10**-12)
+    assert_allclose(model(*x), negy, atol=10**-12)
 
 
 euler_axes_order = ['zxz', 'zyz', 'yzy', 'yxy', 'xyx', 'xzx']
@@ -122,4 +123,4 @@ def test_euler_angles(axes_order):
     model = models.EulerAngleRotation(23.4, 12.2, 34, axes_order)
     mat = model._create_matrix(phi, theta, psi, axes_order)
 
-    utils.assert_allclose(mat.T, matrices[axes_order])  # get_rotation_matrix(axes_order))
+    assert_allclose(mat.T, matrices[axes_order])  # get_rotation_matrix(axes_order))
