@@ -62,8 +62,8 @@ class CCDData(NDDataArray):
     """A class describing basic CCD data.
 
     The CCDData class is based on the NDData object and includes a data array,
-    uncertainty frame, mask frame, meta data, units, and WCS information for a
-    single CCD image.
+    uncertainty frame, mask frame, flag frame, meta data, units, and WCS
+    information for a single CCD image.
 
     Parameters
     -----------
@@ -401,9 +401,15 @@ def _generate_wcs_and_update_header(hdr):
     new_header, wcs
     """
 
-    # Try constructing a WCS object. This may generate a warning, but never
-    # an error.
-    wcs = WCS(hdr)
+    # Try constructing a WCS object.
+    try:
+        wcs = WCS(hdr)
+    except Exception as exc:
+        # Normally WCS only raises Warnings and doesn't fail but in rare
+        # cases (malformed header) it could fail...
+        log.info('An exception happened while extracting WCS informations from '
+                 'the Header.\n{}: {}'.format(type(exc).__name__, str(exc)))
+        return hdr, None
     # Test for success by checking to see if the wcs ctype has a non-empty
     # value, return None for wcs if ctype is empty.
     if not wcs.wcs.ctype[0]:
@@ -498,7 +504,11 @@ def fits_ccddata_reader(filename, hdu=0, unit=None, hdu_uncertainty='UNCERT',
             for i in range(len(hdus)):
                 if hdus.fileinfo(i)['datSpan'] > 0:
                     hdu = i
-                    hdr = hdr + hdus[hdu].header
+                    comb_hdr = hdus[hdu].header.copy()
+                    # Add header values from the primary header that aren't
+                    # present in the extension header.
+                    comb_hdr.extend(hdr, unique=True)
+                    hdr = comb_hdr
                     log.info("first HDU with data is extension "
                              "{0}.".format(hdu))
                     break
@@ -512,10 +522,24 @@ def fits_ccddata_reader(filename, hdu=0, unit=None, hdu_uncertainty='UNCERT',
         else:
             fits_unit_string = None
 
-        if unit is not None and fits_unit_string:
-            log.info("using the unit {0} passed to the FITS reader instead of "
-                     "the unit {1} in the FITS file.".format(unit,
-                                                             fits_unit_string))
+        if fits_unit_string:
+            if unit is None:
+                # Convert the BUNIT header keyword to a unit and if that's not
+                # possible raise a meaningful error message.
+                try:
+                    fits_unit_string = u.Unit(fits_unit_string)
+                except ValueError:
+                    raise ValueError(
+                        'The Header value for the key BUNIT ({}) cannot be '
+                        'interpreted as valid unit. To successfully read the '
+                        'file as CCDData you can pass in a valid `unit` '
+                        'argument explicitly or change the header of the FITS '
+                        'file before reading it.'
+                        .format(fits_unit_string))
+            else:
+                log.info("using the unit {0} passed to the FITS reader instead "
+                         "of the unit {1} in the FITS file."
+                         .format(unit, fits_unit_string))
 
         use_unit = unit or fits_unit_string
         hdr, wcs = _generate_wcs_and_update_header(hdr)
