@@ -68,10 +68,10 @@ def overlap_slices(large_array_shape, small_array_shape, position,
 
     Parameters
     ----------
-    large_array_shape : tuple or int
+    large_array_shape : tuple of int or int
         The shape of the large array (for 1D arrays, this can be an
         `int`).
-    small_array_shape : tuple or int
+    small_array_shape : tuple of int or int
         The shape of the small array (for 1D arrays, this can be an
         `int`).  See the ``mode`` keyword for additional details.
     position : tuple of numbers or number
@@ -97,7 +97,7 @@ def overlap_slices(large_array_shape, small_array_shape, position,
         A tuple of slice objects for each axis of the large array, such
         that ``large_array[slices_large]`` extracts the region of the
         large array that overlaps with the small array.
-    slices_small : slice
+    slices_small : tuple of slices
         A tuple of slice objects for each axis of the small array, such
         that ``small_array[slices_small]`` extracts the region that is
         inside the large array.
@@ -735,6 +735,7 @@ class Cutout2D(object):
         if wcs is not None:
             self.wcs = deepcopy(wcs)
             self.wcs.wcs.crpix -= self._origin_original_true
+            self.wcs._naxis = [self.data.shape[1], self.data.shape[0]]
         else:
             self.wcs = None
 
