@@ -40,7 +40,7 @@ class TestFrame(BaseImageTests):
     @remote_data(source='astropy')
     @pytest.mark.mpl_image_compare(baseline_dir=IMAGE_REFERENCE_DIR,
                                    filename='custom_frame.png',
-                                   tolerance=1.5)
+                                   tolerance=0, style={})
     def test_custom_frame(self):
 
         wcs = WCS(self.msx_header)
@@ -82,7 +82,7 @@ class TestFrame(BaseImageTests):
     @remote_data(source='astropy')
     @pytest.mark.mpl_image_compare(baseline_dir=IMAGE_REFERENCE_DIR,
                                    filename='update_clip_path_rectangular.png',
-                                   tolerance=1.5)
+                                   tolerance=0, style={})
     def test_update_clip_path_rectangular(self, tmpdir):
 
         fig = plt.figure()
@@ -106,7 +106,7 @@ class TestFrame(BaseImageTests):
     @remote_data(source='astropy')
     @pytest.mark.mpl_image_compare(baseline_dir=IMAGE_REFERENCE_DIR,
                                    filename='update_clip_path_nonrectangular.png',
-                                   tolerance=1.5)
+                                   tolerance=0, style={})
     def test_update_clip_path_nonrectangular(self, tmpdir):
 
         fig = plt.figure()
@@ -131,7 +131,7 @@ class TestFrame(BaseImageTests):
     @remote_data(source='astropy')
     @pytest.mark.mpl_image_compare(baseline_dir=IMAGE_REFERENCE_DIR,
                                    filename='update_clip_path_change_wcs.png',
-                                   tolerance=1.5)
+                                   tolerance=0, style={})
     def test_update_clip_path_change_wcs(self, tmpdir):
 
         # When WCS is changed, a new frame is created, so we need to make sure
